@@ -91,7 +91,8 @@ void KTraceDialog::refreshValues()
 	range->setCurrentItem(settings->range);
 
 	item = referenceList->findItem(adc::refToText(settings->reference));
-	reference->setCurrentItem(referenceList->index(item));
+	if(item)
+		reference->setCurrentItem(referenceList->index(item));
 
 	realTime->setChecked(settings->realTime);
 	lowLatency->setChecked(settings->lowLatency);
@@ -170,7 +171,6 @@ void  KTraceDialog::initDialog()
 	comedi_range *rangePtr;
 	const int hsep = 10;	//horizontal seperation between adjacent widgets
 	const int vsep = 10;	//vertical seperation bewteen adjacent widgets
-	const int colTwoX = 320;	// X coordinate of second column
 
 	boardDesc = new QLabel(this);
 	boardDesc->move(hsep, vsep);
@@ -184,59 +184,67 @@ void  KTraceDialog::initDialog()
 	saveData->adjustSize();
 	saveData->move(hsep, boardDesc->geometry().bottom() + vsep);
 
-	browse = new QPushButton("&Browse...", this);
-	browse->move(saveData->x() + hsep, saveData->geometry().bottom() + vsep);
+	fileFrame = new QFrame(this);
+	fileFrame->setFrameStyle(QFrame::Panel | QFrame::Sunken);
+	fileFrame->setMargin(hsep);
+	fileFrame->move(saveData->x() + hsep, saveData->geometry().bottom() + vsep);
+
+	browse = new QPushButton("&Browse...", fileFrame);
+	browse->move(fileFrame->margin(), fileFrame->margin());
 	browse->adjustSize();
 
-	directory = new QLineEdit(this);
+	directory = new QLineEdit(fileFrame);
 	directory->setGeometry(browse->geometry().right() + hsep, browse->y(), 250, directory->sizeHint().height());
 	QWhatsThis::add(directory, "Directory where data will be saved");
 
-	directoryLabel = new QLabel(this);
+	directoryLabel = new QLabel(fileFrame);
 	directoryLabel->move(directory->geometry().right() + hsep, directory->y());
 	directoryLabel->setText("Directory");
 	directoryLabel->adjustSize();
 
-	fileName = new QLineEdit(this);
+	fileName = new QLineEdit(fileFrame);
 	fileName->move(browse->x(), browse->geometry().bottom() + vsep);
 	fileName->adjustSize();
 	QWhatsThis::add(fileName, "The file stem of the saved data file.  The file number "
 		"and a file type extension will be appended");
 
-	fileNameLabel = new QLabel(this);
+	fileNameLabel = new QLabel(fileFrame);
 	fileNameLabel->setText("File stem");
 	fileNameLabel->move(fileName->geometry().right() + hsep, fileName->y());
 	fileNameLabel->adjustSize();
 
-	fileNum = new QSpinBox(this);
+	fileNum = new QSpinBox(fileFrame);
 	fileNum->move(fileName->x(), fileName->geometry().bottom() + vsep);
 	fileNum->setRange(0, 999);
 	fileNum->adjustSize();
 	QWhatsThis::add(fileNum, "The file number.  It is appended to the file stem");
 
-	fileNumLabel = new QLabel(this);
+	fileNumLabel = new QLabel(fileFrame);
 	fileNumLabel->move(fileNum->geometry().right() + hsep, fileNum->y());
 	fileNumLabel->setText("File number");
 	fileNumLabel->adjustSize();
 
-	saveType = new QComboBox(false, this);
+	saveType = new QComboBox(false, fileFrame);
 	saveType->move(fileNum->x(), fileNum->geometry().bottom() + vsep);
 	saveType->insertItem("Tab delimited text", TEXT);
 	saveType->insertItem("Gzipped text", GZ_TEXT);
 	saveType->insertItem("True binary (deprecated)", BINARY);
 	saveType->adjustSize();
 	QWhatsThis::add(saveType, "Format for the saved data file.  'True binary' was included "
-		"for backward compatiblity with my lab's previous data taking software.  You "
-		"probably don't want to use 'true binary'.");
+		"for backward compatiblity with my lab's previous data taking software.  It stores "
+		"data as an array of 16 bit integers (signed or unsigned for bipolar/unipolar ranges) "
+		"with little endian byte ordering.");
 
-	saveTypeLabel = new QLabel(this);
+	saveTypeLabel = new QLabel(fileFrame);
 	saveTypeLabel->move(saveType->geometry().right() + hsep, saveType->y());
 	saveTypeLabel->setText("Save File Format");
 	saveTypeLabel->adjustSize();
 
-	startTrigger = new QComboBox(false, this);
-	startTrigger->move(saveData->x(), saveType->geometry().bottom() + vsep);
-	startTriggerList = new QListBox(this);
+	leftColumn = new QWidget(this);
+
+	startTrigger = new QComboBox(false, leftColumn);
+	startTrigger->move(0, 0);
+	startTriggerList = new QListBox(leftColumn);
 	if(myADC->startTriggerMask() & TRIG_NOW)
 		startTriggerList->insertItem(adc::trigToText(TRIG_NOW));
 	if(myADC->startTriggerMask() & TRIG_EXT)
@@ -248,25 +256,25 @@ void  KTraceDialog::initDialog()
 		startTrigger->setEnabled(false);
 	QWhatsThis::add(startTrigger, "The trigger which begins data aquisition");
 
-	startTriggerLabel = new QLabel(this);
+	startTriggerLabel = new QLabel(leftColumn);
 	startTriggerLabel->move(startTrigger->geometry().right() + hsep, startTrigger->y());
 	startTriggerLabel->setText("Start Trigger");
 	startTriggerLabel->adjustSize();
 
-	numChannels = new QSpinBox(this);
+	numChannels = new QSpinBox(leftColumn);
 	numChannels->move(startTrigger->x(), startTrigger->geometry().bottom() + vsep);
 	numChannels->setRange(1, myADC->numChannels());
 	numChannels->adjustSize();
 	QWhatsThis::add(numChannels, "The number of channels to be read for each scan");
 
-	numChannelsLabel = new QLabel(this);
+	numChannelsLabel = new QLabel(leftColumn);
 	numChannelsLabel->move(numChannels->geometry().right() + hsep, numChannels->y());
 	numChannelsLabel->setText("Number of channels");
 	numChannelsLabel->adjustSize();
 
-	scanTrigger = new QComboBox(false, this);
+	scanTrigger = new QComboBox(false, leftColumn);
 	scanTrigger->move(numChannels->x(), numChannels->geometry().bottom() + vsep);
-	scanTriggerList = new QListBox(this);
+	scanTriggerList = new QListBox(leftColumn);
 	if(myADC->scanTriggerMask() & TRIG_TIMER)
 		scanTriggerList->insertItem(adc::trigToText(TRIG_TIMER));
 	if(myADC->scanTriggerMask() & TRIG_FOLLOW)
@@ -282,25 +290,25 @@ void  KTraceDialog::initDialog()
 		adc::trigToText(TRIG_FOLLOW) + "' trigger makes scans follow the "
 		"conversion trigger.");
 
-	scanTriggerLabel = new QLabel(this);
+	scanTriggerLabel = new QLabel(leftColumn);
 	scanTriggerLabel->move(scanTrigger->geometry().right() + hsep, scanTrigger->y());
 	scanTriggerLabel->setText("Scan Trigger");
 	scanTriggerLabel->adjustSize();
 
-	scanFrequency = new QLineEdit(this);
+	scanFrequency = new QLineEdit(leftColumn);
 	scanFrequency->move(scanTrigger->x(), scanTrigger->geometry().bottom() + vsep);
 	scanFrequency->adjustSize();
 	QWhatsThis::add(scanFrequency, "Determines the frequency with which scans are taken "
 		"when based on a '" + adc::trigToText(TRIG_TIMER) + "' trigger");
 
-	scanFrequencyLabel = new QLabel(this);
+	scanFrequencyLabel = new QLabel(leftColumn);
 	scanFrequencyLabel->move(scanFrequency->geometry().right() + hsep, scanFrequency->y());
 	scanFrequencyLabel->setText("Scan Frequency (Hz)");
 	scanFrequencyLabel->adjustSize();
 
-	conversionTrigger = new QComboBox(false, this);
+	conversionTrigger = new QComboBox(false, leftColumn);
 	conversionTrigger->move(scanFrequency->x(), scanFrequency->geometry().bottom() + vsep);
-	conversionTriggerList = new QListBox(this);
+	conversionTriggerList = new QListBox(leftColumn);
 	if(myADC->conversionTriggerMask() & TRIG_TIMER)
 		conversionTriggerList->insertItem(adc::trigToText(TRIG_TIMER));
 	if(myADC->conversionTriggerMask() & TRIG_NOW)
@@ -316,25 +324,25 @@ void  KTraceDialog::initDialog()
 		"a scan.  The '" + adc::trigToText(TRIG_NOW) + "' trigger means to complete the scan "
 		"as quickly as possible.");
 
-	conversionTriggerLabel = new QLabel("Conversion Trigger", this);
+	conversionTriggerLabel = new QLabel("Conversion Trigger", leftColumn);
 	conversionTriggerLabel->move(conversionTrigger->geometry().right() + hsep, conversionTrigger->y());
 	conversionTriggerLabel->adjustSize();
 
-	conversionFrequency = new QLineEdit(this);
+	conversionFrequency = new QLineEdit(leftColumn);
 	conversionFrequency->move(conversionTrigger->x(), conversionTrigger->geometry().bottom() + vsep);
 	conversionFrequency->adjustSize();
 	QWhatsThis::add(conversionFrequency, "Determines the frequency with which conversions are made "
 		"when the conversion trigger is '" + adc::trigToText(TRIG_TIMER) + "'.  "
 		"May be overriden by scan frequency if scan trigger is '"+ adc::trigToText(TRIG_FOLLOW) +"'");
 
-	conversionFrequencyLabel = new QLabel(this);
+	conversionFrequencyLabel = new QLabel(leftColumn);
 	conversionFrequencyLabel->move(conversionFrequency->geometry().right() + hsep, conversionFrequency->y());
 	conversionFrequencyLabel->setText("Conversion Frequency (Hz)");
 	conversionFrequencyLabel->adjustSize();
 
-	stopTrigger = new QComboBox(false, this);
+	stopTrigger = new QComboBox(false, leftColumn);
 	stopTrigger->move(conversionFrequency->x(), conversionFrequency->geometry().bottom() + vsep);
-	stopTriggerList = new QListBox(this);
+	stopTriggerList = new QListBox(leftColumn);
 	if(myADC->stopTriggerMask() & TRIG_COUNT)
 		stopTriggerList->insertItem(adc::trigToText(TRIG_COUNT));
 	if(myADC->stopTriggerMask() & TRIG_NONE)
@@ -348,22 +356,22 @@ void  KTraceDialog::initDialog()
 		stopTrigger->setEnabled(false);
 	QWhatsThis::add(stopTrigger, "The trigger which ends data aquisition.");
 
-	stopTriggerLabel = new QLabel("Stop Trigger", this);
+	stopTriggerLabel = new QLabel("Stop Trigger", leftColumn);
 	stopTriggerLabel->move(stopTrigger->geometry().right() + hsep, stopTrigger->y());
 	stopTriggerLabel->adjustSize();
 
-	numScans = new QSpinBox(this);
+	numScans = new QSpinBox(leftColumn);
 	numScans->move(stopTrigger->x(), stopTrigger->geometry().bottom() + vsep);
 	numScans->setRange(1, pow(2, 31) - 1);
 	numScans->adjustSize();
 	QWhatsThis::add(numScans, "The total number of scans to perform");
 
-	numScansLabel = new QLabel(this);
+	numScansLabel = new QLabel(leftColumn);
 	numScansLabel->move(numScans->geometry().right() + hsep, numScans->y());
 	numScansLabel->setText("Number of scans");
 	numScansLabel->adjustSize();
 
-	range = new QComboBox(false, this);
+	range = new QComboBox(false, leftColumn);
 	range->move(numScans->x(), numScans->geometry().bottom() + vsep);
 	for(int i = 0; (rangePtr = myADC->getRange(i)); i++)
 	{
@@ -386,14 +394,14 @@ void  KTraceDialog::initDialog()
 		range->setEnabled(false);
 	QWhatsThis::add(range,"The desired input range for your daq card");
 
-	rangeLabel = new QLabel(this);
+	rangeLabel = new QLabel(leftColumn);
 	rangeLabel->move(range->geometry().right() + hsep, range->y());
 	rangeLabel->setText("Analog input range");
 	rangeLabel->adjustSize();
 
 	unsigned int subdevFlags = myADC->subdevFlags();
-	reference = new QComboBox(false, this);
-	referenceList = new QListBox(this);
+	reference = new QComboBox(false, leftColumn);
+	referenceList = new QListBox(leftColumn);
 	reference->move(range->x(), range->geometry().bottom() + vsep);
 	if(subdevFlags & SDF_GROUND)
 		referenceList->insertItem(adc::refToText(AREF_GROUND));
@@ -413,15 +421,17 @@ void  KTraceDialog::initDialog()
 	QWhatsThis::add(reference, "The desired input reference for your daq card.  "
 		"It will be ignored if your card's input reference is not software programmable.");
 
-	referenceLabel = new QLabel(this);
+	referenceLabel = new QLabel(leftColumn);
 	referenceLabel->move(reference->geometry().right() + hsep, reference->y());
 	referenceLabel->setText("Analog input reference");
 	referenceLabel->adjustSize();
 
 	// second column
+	
+	rightColumn = new QWidget(this);
 
-	realTime = new QCheckBox(this);
-	realTime->move(colTwoX, startTrigger->y());
+	realTime = new QCheckBox(rightColumn);
+	realTime->move(0, 0);
 	realTime->setText("Request real-time interrupts");
 	realTime->adjustSize();
 	QWhatsThis::add(realTime,
@@ -431,7 +441,7 @@ void  KTraceDialog::initDialog()
 		"This option can be useful if you are "
 		"taking data at high frequency or have a card with a small onboard fifo.");
 
-	lowLatency = new QCheckBox(this);
+	lowLatency = new QCheckBox(rightColumn);
 	lowLatency->move(realTime->x(), realTime->geometry().bottom() + vsep);
 	lowLatency->setText("Request low latency mode");
 	lowLatency->adjustSize();
@@ -444,38 +454,56 @@ void  KTraceDialog::initDialog()
 		"executed before aquisition begins.  If you are saving data to disk, the "
 		"shell variable KTT_DATA_FILE "
 		"will be set to the name of your data file (except when using the deprecated "
-		"binary format, in which case the extension .ts? is left off).";
+		"binary format, in which case the extension .ts? is left off).  Also, KTT_PARAM_FILE "
+		"will contain the name of the parameter file.";
 
-	execAtStart = new QCheckBox(this);
+	execAtStart = new QCheckBox(rightColumn);
 	execAtStart->move(lowLatency->x(), lowLatency->geometry().bottom() + vsep);
 	execAtStart->setText("Execute shell command at start of aquisition");
 	execAtStart->adjustSize();
 	QWhatsThis::add(execAtStart, execAtStartHelp);
 
-	startCommand = new QMultiLineEdit(this);
+	startCommand = new QMultiLineEdit(rightColumn);
 	startCommand->move(execAtStart->x() + hsep, execAtStart->geometry().bottom() + vsep);
-	startCommand->setFixedVisibleLines(4);
-	startCommand->adjustSize();
+#if QT_VERSION >= 300
+	startCommand->setWordWrap(QTextEdit::NoWrap);
+#endif
+	startCommand->setFixedHeight(5 * startCommand->fontMetrics().height());
+	startCommand->setFixedWidth(execAtStart->geometry().right() - startCommand->geometry().left());
 	QWhatsThis::add(startCommand, execAtStartHelp);
 
 	QString execAtEndHelp = "You can enter shell commands which will be "
 		"executed when aquisition is completed.  If you are saving data to disk, the "
 		"shell variable KTT_DATA_FILE "
 		"will be set to the name of your data file (except when using the deprecated  "
-		"binary format, in which case the extension .ts? is left off).";
+		"binary format, in which case the extension .ts? is left off).  Also, KTT_PARAM_FILE "
+		"will contain the name of the parameter file.";
 
-	execAtEnd = new QCheckBox(this);
+	execAtEnd = new QCheckBox(rightColumn);
 	execAtEnd->move(execAtStart->x(), startCommand->geometry().bottom() + vsep);
 	execAtEnd->setText("Execute shell command at end of aquisition");
 	execAtEnd->adjustSize();
 	QWhatsThis::add(execAtEnd, execAtEndHelp);
 
-	endCommand = new QMultiLineEdit(this);
+	endCommand = new QMultiLineEdit(rightColumn);
 	endCommand->move(execAtEnd->x() + hsep, execAtEnd->geometry().bottom() + vsep);
-	endCommand->setFixedVisibleLines(4);
-	endCommand->adjustSize();
+#if QT_VERSION >= 300
+	endCommand->setWordWrap(QTextEdit::NoWrap);
+#endif
+	endCommand->setFixedHeight(5 * endCommand->fontMetrics().height());
+	endCommand->setFixedWidth(startCommand->width());
 	QWhatsThis::add(endCommand, execAtEndHelp);
 
+	// done with second column
+
+	fileFrame->adjustSize();
+
+	leftColumn->adjustSize();
+	leftColumn->move(hsep, fileFrame->geometry().bottom() + vsep);
+
+	rightColumn->adjustSize();
+	rightColumn->move(leftColumn->geometry().right() + 2 * hsep, leftColumn->y());
+
 	adjustSize();
 
 	okButton = new QPushButton("&OK", this);
